summaryrefslogtreecommitdiff
path: root/src/pptxt/PPTxtHandler.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/pptxt/PPTxtHandler.java')
-rwxr-xr-xsrc/pptxt/PPTxtHandler.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/pptxt/PPTxtHandler.java b/src/pptxt/PPTxtHandler.java
index 55813a8..4a16842 100755
--- a/src/pptxt/PPTxtHandler.java
+++ b/src/pptxt/PPTxtHandler.java
@@ -3,7 +3,7 @@ package pptxt;
/*----------------------------------------------------------------------------*/
/*-- PPTxtHandler.java - handles generation 5 games text encoding --*/
/*-- Code derived from "PPTXT", copyright (C) SCV? --*/
/*-- Ported to Java and bugfixed/customized by rafa_99 --*/
/*----------------------------------------------------------------------------*/
import java.io.FileNotFoundException;
@@ -15,7 +15,7 @@ import java.util.Scanner;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
-import com.rafa_99.pkrandom.FileFunctions;
+import com.sneed.pkrandom.FileFunctions;
public class PPTxtHandler {
@@ -3,7 +3,7 @@ package pptxt;
/*-- PPTxtHandler.java - handles generation 5 games text encoding --*/
/*-- Code derived from "PPTXT", copyright (C) SCV? --*/
-/*-- Ported to Java and bugfixed/customized by rafa_99 --*/
+/*-- Ported to Java and bugfixed/customized by sneed --*/
/*----------------------------------------------------------------------------*/
import java.io.FileNotFoundException;